Raptacon3200 - Common Library
==============================================

Documentation
=============

* Raptacon3200 documentation: 
* Installation: 

Contributing new changes
========================

1. [Fork this git repository](https://github.com/raptacon...) to your github account
2. Create your feature branch (`git checkout -b my-new-feature`)
3. Commit your changes (`git commit -am 'Add some feature'`)
4. Push to the branch (`git push -u origin my-new-feature`)
5. Create new Pull Request on github


Authors
=======

Nathan Beasley (nathan@.com)
Chris Hirsch (chris@base2technology.com)

Contributors:

* Others
